==> symfony_6.4.5+dfsg.orig.tar.xz: symfony-6.4.5/src/Symfony/Component/Intl/Resources/data/languages/fo.php <==
<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhasiskt',
        'ace' => 'achinese',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'af' => 'afrikaans',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'ale' => 'aleut',
        'alt' => 'suður altai',
        'am' => 'amhariskt',
        'an' => 'aragoniskt',
        'anp' => 'angika',
        'ar' => 'arabiskt',
        'arn' => 'mapuche',
        'arp' => 'arapaho',
        'as' => 'assamesiskt',
        'asa' => 'asu',
        'ast' => 'asturianskt',
        'av' => 'avariskt',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'aserbajdsjanskt',
        'ba' => 'bashkir',
        'ban' => 'balinesiskt',
        'bas' => 'basaa',
        'be' => 'hvitarussiskt',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bulgarskt',
        'bgn' => 'vestur balochi',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bangla',
        'bo' => 'tibetskt',
        'br' => 'bretonskt',
        'brx' => 'bodo',
        'bs' => 'bosniskt',
        'bss' => 'bakossi',
        'bug' => 'buginesiskt',
        'byn' => 'blin',
        'ca' => 'katalani',
        'ccp' => 'khakma',
        'ce' => 'tjetjenskt',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'cho' => 'choctaw',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'miðkurdiskt',
        'co' => 'korsikanskt',
        'crs' => 'seselwa creole franskt',
        'cs' => 'kekkiskt',
        'cu' => 'kirkju sláviskt',
        'cv' => 'chuvash',
        'cy' => 'walisiskt',
        'da' => 'danskt',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'týskt',
        'dgr' => 'dogrib',
        'dje' => 'sarma',
        'dsb' => 'lágt sorbian',
        'dua' => 'duala',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'eka' => 'ekajuk',
        'el' => 'grikskt',
        'en' => 'enskt',
        'eo' => 'esperanto',
        'es' => 'spanskt',
        'et' => 'estiskt',
        'eu' => 'baskiskt',
        'ewo' => 'ewondo',
        'fa' => 'persiskt',
        'ff' => 'fulah',
        'fi' => 'finskt',
        'fil' => 'filipiniskt',
        'fj' => 'fijimál',
        'fo' => 'føroyskt',
        'fon' => 'fon',
        'fr' => 'franskt',
        'fur' => 'friuliskt',
        'fy' => 'vestur frísiskt',
        'ga' => 'írskt',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gan' => 'gan kinesiskt',
        'gd' => 'skotskt gæliskt',
        'gez' => 'geez',
        'gil' => 'kiribatiskt',
        'gl' => 'galisiskt',
        'gn' => 'guarani',
        'gor' => 'gorontalo',
        'gsw' => 'týskt (Sveis)',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwich’in',
        'ha' => 'hausa',
        'hak' => 'hakka kinesiskt',
        'haw' => 'hawaiianskt',
        'he' => 'hebraiskt',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hmn' => 'hmong',
        'hr' => 'kroatiskt',
        'hsb' => 'ovara sorbian',
        'hsn' => 'xiang kinesiskt',
        'ht' => 'haitiskt creole',
        'hu' => 'ungarskt',
        'hup' => 'hupa',
        'hy' => 'armenskt',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesiskt',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ilo' => 'iloko',
        'inh' => 'inguish',
        'io' => 'ido',
        'is' => 'íslendskt',
        'it' => 'italskt',
        'iu' => 'inuktitut',
        'ja' => 'japanskt',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'javanskt',
        'ka' => 'georgiskt',
        'kab' => 'kabyle',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'kabardinskt',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'grønhøvdaoyggjarskt',
        'kfo' => 'koro',
        'kha' => 'khasi',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazakh',
        'kkj' => 'kako',
        'kl' => 'kalaallisut',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreanskt',
        'koi' => 'komi-permyak',
        'kok' => 'konkani',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-balkar',
        'krl' => 'karelskt',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kølnskt',
        'ku' => 'kurdiskt',
        'kum' => 'kumyk',
        'kv' => 'komi',
        'kw' => 'corniskt',
        'ky' => 'kyrgyz',
        'la' => 'latín',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lb' => 'luksemborgskt',
        'lez' => 'lezghian',
        'lg' => 'ganda',
        'li' => 'limburgiskt',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laoskt',
        'loz' => 'lozi',
        'lrc' => 'norður luri',
        'lt' => 'litaviskt',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'lettiskt',
        'mad' => 'maduresiskt',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagassiskt',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'metaʼ',
        'mh' => 'marshallesiskt',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'makedónskt',
        'ml' => 'malayalam',
        'mn' => 'mongolskt',
        'mni' => 'manupuri',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malaiiskt',
        'mt' => 'maltiskt',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandesiskt',
        'my' => 'burmesiskt',
        'myv' => 'erzya',
        'mzn' => 'mazanderani',
        'na' => 'nauru',
        'nan' => 'min nan kinesiskt',
        'nap' => 'napolitanskt',
        'naq' => 'nama',
        'nb' => 'norskt bókmál',
        'nd' => 'norður ndebele',
        'nds' => 'lágt týskt',
        'ne' => 'nepalskt',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niuean',
        'nl' => 'hálendskt',
        'nmg' => 'kwasio',
        'nn' => 'nýnorskt',
        'nnh' => 'ngiemboon',
        'no' => 'norskt',
        'nog' => 'nogai',
        'nqo' => 'nʼko',
        'nr' => 'suður ndebele',
        'nso' => 'norður sotho',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'ny' => 'nyanja',
        'nyn' => 'nyankole',
        'oc' => 'occitanskt',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'ossetiskt',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauan',
        'pcm' => 'nigeriskt pidgin',
        'pl' => 'pólskt',
        'prg' => 'prusslanskt',
        'ps' => 'pashto',
        'pt' => 'portugiskiskt',
        'qu' => 'quechua',
        'quc' => 'kʼicheʼ',
        'rap' => 'rapanui',
        'rar' => 'rarotongiskt',
        'rm' => 'retoromanskt',
        'rn' => 'rundi',
        'ro' => 'rumenskt',
        'rof' => 'rombo',
        'ru' => 'russiskt',
        'rup' => 'aromenskt',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandawe',
        'sah' => 'sakha',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardiskt',
        'scn' => 'sisilanskt',
        'sco' => 'skotskt',
        'sd' => 'sindhi',
        'sdh' => 'suður kurdiskt',
        'se' => 'norður sámiskt',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sh' => 'serbokroatiskt',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'si' => 'singalesiskt',
        'sk' => 'slovakiskt',
        'sl' => 'slovenskt',
        'sm' => 'sámoiskt',
        'sma' => 'suður sámiskt',
        'smj' => 'lule sámiskt',
        'smn' => 'inari sami',
        'sms' => 'skolt sámiskt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somaliskt',
        'sq' => 'albanskt',
        'sr' => 'serbiskt',
        'srn' => 'sranan tongo',
        'ss' => 'swatiskt',
        'ssy' => 'saho',
        'st' => 'sesotho',
        'su' => 'sundanesiskt',
        'suk' => 'sukuma',
        'sv' => 'svenskt',
        'sw' => 'swahili',
        'swb' => 'komoriskt',
        'syr' => 'syriac',
        'ta' => 'tamilskt',
        'te' => 'telugu',
        'tem' => 'timne',
        'teo' => 'teso',
        'tet' => 'tetum',
        'tg' => 'tajik',
        'th' => 'tailendskt',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tk' => 'turkmenskt',
        'tl' => 'tagalog',
        'tlh' => 'klingonskt',
        'tn' => 'tswana',
        'to' => 'tonganskt',
        'tpi' => 'tok pisin',
        'tr' => 'turkiskt',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tatar',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiskt',
        'tyv' => 'tuvinian',
        'tzm' => 'miðatlasfjøll tamazight',
        'udm' => 'udmurt',
        'ug' => 'uyghur',
        'uk' => 'ukrainskt',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'usbekiskt',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vjetnamesiskt',
        'vo' => 'volapykk',
        'vun' => 'vunjo',
        'wa' => 'walloon',
        'wae' => 'walser',
        'wal' => 'wolaytta',
        'war' => 'waray',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'wu kinesiskt',
        'xal' => 'kalmyk',
        'xh' => 'xhosa',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'jiddiskt',
        'yo' => 'yoruba',
        'yue' => 'kantonesiskt',
        'zgh' => 'vanligt marokanskt tamazight',
        'zh' => 'kinesiskt',
        'zu' => 'sulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'nútíðar vanligt arabiskt',
        'de_CH' => 'høgt týskt (Sveis)',
        'fa_AF' => 'dari',
        'nds_NL' => 'lágt saksiskt',
        'nl_BE' => 'flamskt',
        'pt_BR' => 'portugiskiskt (Brasilia)',
        'pt_PT' => 'portugiskiskt (Evropa)',
        'ro_MD' => 'moldaviskt',
        'sw_CD' => 'kongo svahili',
        'zh_Hans' => 'einkult kinesiskt',
        'zh_Hant' => 'vanligt kinesiskt',
    ],
];

==> symfony_7.4.2+dfsg.orig.tar.xz: symfony-7.4.2/src/Symfony/Component/Intl/Resources/data/languages/fo.php <==
<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhasiskt',
        'ace' => 'achinese',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'af' => 'afrikaans',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'ale' => 'aleut',
        'alt' => 'suður altai',
        'am' => 'amhariskt',
        'an' => 'aragoniskt',
        'anp' => 'angika',
        'ar' => 'arabiskt',
        'arn' => 'mapuche',
        'arp' => 'arapaho',
        'as' => 'assamesiskt',
        'asa' => 'asu',
        'ast' => 'asturianskt',
        'av' => 'avariskt',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'aserbajdsjanskt',
        'ba' => 'bashkir',
        'ban' => 'balinesiskt',
        'bas' => 'basaa',
        'be' => 'hvitarussiskt',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bulgarskt',
        'bgc' => 'haryanvi',
        'bgn' => 'vestur balochi',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'siksika',
        'blo' => 'anii',
        'bm' => 'bambara',
        'bn' => 'bangla',
        'bo' => 'tibetskt',
        'br' => 'bretonskt',
        'brx' => 'bodo',
        'bs' => 'bosniskt',
        'bss' => 'bakossi',
        'bug' => 'buginesiskt',
        'byn' => 'blin',
        'ca' => 'katalani',
        'ccp' => 'khakma',
        'ce' => 'tjetjenskt',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'cho' => 'choctaw',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'miðkurdiskt',
        'co' => 'korsikanskt',
        'crs' => 'seselwa creole franskt',
        'cs' => 'kekkiskt',
        'csw' => 'swampy cree',
        'cu' => 'kirkju sláviskt',
        'cv' => 'chuvash',
        'cy' => 'walisiskt',
        'da' => 'danskt',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'týskt',
        'dgr' => 'dogrib',
        'dje' => 'sarma',
        'doi' => 'dogri',
        'dsb' => 'lágt sorbian',
        'dua' => 'duala',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'eka' => 'ekajuk',
        'el' => 'grikskt',
        'en' => 'enskt',
        'eo' => 'esperanto',
        'es' => 'spanskt',
        'et' => 'estiskt',
        'eu' => 'baskiskt',
        'ewo' => 'ewondo',
        'fa' => 'persiskt',
        'ff' => 'fulah',
        'fi' => 'finskt',
        'fil' => 'filipiniskt',
        'fj' => 'fijimál',
        'fo' => 'føroyskt',
        'fon' => 'fon',
        'fr' => 'franskt',
        'fur' => 'friuliskt',
        'fy' => 'vestur frísiskt',
        'ga' => 'írskt',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gan' => 'gan kinesiskt',
        'gd' => 'skotskt gæliskt',
        'gez' => 'geez',
        'gil' => 'kiribatiskt',
        'gl' => 'galisiskt',
        'gn' => 'guarani',
        'gor' => 'gorontalo',
        'gsw' => 'týskt (Sveis)',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwich’in',
        'ha' => 'hausa',
        'hak' => 'hakka kinesiskt',
        'haw' => 'hawaiianskt',
        'he' => 'hebraiskt',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hmn' => 'hmong',
        'hr' => 'kroatiskt',
        'hsb' => 'ovara sorbian',
        'hsn' => 'xiang kinesiskt',
        'ht' => 'haitiskt creole',
        'hu' => 'ungarskt',
        'hup' => 'hupa',
        'hy' => 'armenskt',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesiskt',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ilo' => 'iloko',
        'inh' => 'inguish',
        'io' => 'ido',
        'is' => 'íslendskt',
        'it' => 'italskt',
        'iu' => 'inuktitut',
        'ja' => 'japanskt',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'javanskt',
        'ka' => 'georgiskt',
        'kab' => 'kabyle',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'kabardinskt',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'grønhøvdaoyggjarskt',
        'kfo' => 'koro',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazakh',
        'kkj' => 'kako',
        'kl' => 'kalaallisut',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreanskt',
        'koi' => 'komi-permyak',
        'kok' => 'konkani',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-balkar',
        'krl' => 'karelskt',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kølnskt',
        'ku' => 'kurdiskt',
        'kum' => 'kumyk',
        'kv' => 'komi',
        'kw' => 'corniskt',
        'kxv' => 'kuvi',
        'ky' => 'kyrgyz',
        'la' => 'latín',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lb' => 'luksemborgskt',
        'lez' => 'lezghian',
        'lg' => 'ganda',
        'li' => 'limburgiskt',
        'lij' => 'liguriskt',
        'lkt' => 'lakota',
        'lmo' => 'lombard',
        'ln' => 'lingala',
        'lo' => 'laoskt',
        'loz' => 'lozi',
        'lrc' => 'norður luri',
        'lt' => 'litaviskt',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lun' => 'lunda',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'lettiskt',
        'mad' => 'maduresiskt',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagassiskt',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'metaʼ',
        'mh' => 'marshallesiskt',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'makedónskt',
        'ml' => 'malayalam',
        'mn' => 'mongolskt',
        'mni' => 'manupuri',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malaiiskt',
        'mt' => 'maltiskt',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandesiskt',
        'my' => 'burmesiskt',
        'myv' => 'erzya',
        'mzn' => 'mazanderani',
        'na' => 'nauru',
        'nan' => 'min nan kinesiskt',
        'nap' => 'napolitanskt',
        'naq' => 'nama',
        'nb' => 'norskt bókmál',
        'nd' => 'norður ndebele',
        'nds' => 'lágt týskt',
        'ne' => 'nepalskt',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niuean',
        'nl' => 'hálendskt',
        'nmg' => 'kwasio',
        'nn' => 'nýnorskt',
        'nnh' => 'ngiemboon',
        'no' => 'norskt',
        'nog' => 'nogai',
        'nqo' => 'nʼko',
        'nr' => 'suður ndebele',
        'nso' => 'norður sotho',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'ny' => 'nyanja',
        'nyn' => 'nyankole',
        'oc' => 'occitanskt',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'ossetiskt',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauan',
        'pcm' => 'nigeriskt pidgin',
        'pl' => 'pólskt',
        'prg' => 'prusslanskt',
        'ps' => 'pashto',
        'pt' => 'portugiskiskt',
        'qu' => 'quechua',
        'quc' => 'kʼicheʼ',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotongiskt',
        'rm' => 'retoromanskt',
        'rn' => 'rundi',
        'ro' => 'rumenskt',
        'rof' => 'rombo',
        'ru' => 'russiskt',
        'rup' => 'aromenskt',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandawe',
        'sah' => 'sakha',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardiskt',
        'scn' => 'sisilanskt',
        'sco' => 'skotskt',
        'sd' => 'sindhi',
        'sdh' => 'suður kurdiskt',
        'se' => 'norður sámiskt',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sh' => 'serbokroatiskt',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'si' => 'singalesiskt',
        'sk' => 'slovakiskt',
        'sl' => 'slovenskt',
        'sm' => 'sámoiskt',
        'sma' => 'suður sámiskt',
        'smj' => 'lule sámiskt',
        'smn' => 'inari sami',
        'sms' => 'skolt sámiskt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somaliskt',
        'sq' => 'albanskt',
        'sr' => 'serbiskt',
        'srn' => 'sranan tongo',
        'ss' => 'swatiskt',
        'ssy' => 'saho',
        'st' => 'sesotho',
        'su' => 'sundanesiskt',
        'suk' => 'sukuma',
        'sv' => 'svenskt',
        'sw' => 'swahili',
        'swb' => 'komoriskt',
        'syr' => 'syriac',
        'szl' => 'silesiskt',
        'ta' => 'tamilskt',
        'te' => 'telugu',
        'tem' => 'timne',
        'teo' => 'teso',
        'tet' => 'tetum',
        'tg' => 'tajik',
        'th' => 'tailendskt',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tk' => 'turkmenskt',
        'tl' => 'tagalog',
        'tlh' => 'klingonskt',
        'tn' => 'tswana',
        'to' => 'tonganskt',
        'tpi' => 'tok pisin',
        'tr' => 'turkiskt',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tatar',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiskt',
        'tyv' => 'tuvinian',
        'tzm' => 'miðatlasfjøll tamazight',
        'udm' => 'udmurt',
        'ug' => 'uyghur',
        'uk' => 'ukrainskt',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'usbekiskt',
        've' => 'venda',
        'vec' => 'venetiskt',
        'vi' => 'vjetnamesiskt',
        'vmw' => 'makhuwa',
        'vo' => 'volapykk',
        'vun' => 'vunjo',
        'wa' => 'walloon',
        'wae' => 'walser',
        'wal' => 'wolaytta',
        'war' => 'waray',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'wu kinesiskt',
        'xal' => 'kalmyk',
        'xh' => 'xhosa',
        'xnr' => 'kangri',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'jiddiskt',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'kantonesiskt',
        'za' => 'zhuang',
        'zgh' => 'vanligt marokanskt tamazight',
        'zh' => 'kinesiskt',
        'zu' => 'sulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'nútíðar vanligt arabiskt',
        'de_CH' => 'høgt týskt (Sveis)',
        'fa_AF' => 'dari',
        'nds_NL' => 'lágt saksiskt',
        'nl_BE' => 'flamskt',
        'pt_BR' => 'portugiskiskt (Brasilia)',
        'pt_PT' => 'portugiskiskt (Evropa)',
        'ro_MD' => 'moldaviskt',
        'sw_CD' => 'kongo svahili',
        'zh_Hans' => 'einkult kinesiskt',
        'zh_Hant' => 'vanligt kinesiskt',
    ],
];
